'use strict';

var axios = require('axios');
var rax = require('@iris-platform/retryable-axios');
var isClientToken = require('../utils/is-client-token');

var _require = require('../utils/constants'),
    ApiVersion = _require.ApiVersion;

var _require2 = require('../errors'),
    IdsRequestError = _require2.IdsRequestError,
    IdsRequestSetupError = _require2.IdsRequestSetupError,
    InvalidOrMissingParameterError = _require2.InvalidOrMissingParameterError;

var requiredParam = require('../utils/required-param');

var createOrUpdateObject = async function createOrUpdateObject(_ref) {
  var _ref$url = _ref.url,
      url = _ref$url === undefined ? requiredParam('url') : _ref$url,
      _ref$token = _ref.token,
      token = _ref$token === undefined ? requiredParam('token') : _ref$token,
      _ref$className = _ref.className,
      className = _ref$className === undefined ? requiredParam('className') : _ref$className,
      _ref$query = _ref.query,
      query = _ref$query === undefined ? requiredParam('query') : _ref$query,
      _ref$object = _ref.object,
      object = _ref$object === undefined ? requiredParam('object') : _ref$object,
      userId = _ref.userId;

  var isClient = isClientToken(token);

  if (!isClient && !userId) throw new InvalidOrMissingParameterError('userId');

  var interceptorId = rax.attach();
  var ax = await axios({
    method: 'put',
    url: isClient ? url + '/' + ApiVersion + '/classes/' + className + '/objects' : url + '/' + ApiVersion + '/classes/' + className + '/objects/userid/' + userId,
    timeout: 10000,
    headers: {
      "Content-Type": "application/json",
      "Authorization": 'Bearer ' + token
    },
    data: {
      query: query,
      object: object
    },
    raxConfig: {}
  }).then(function (response) {
    return response.data;
  }).catch(function (error) {
    if (error.response) {
      throw new Error(error.response.data.message ? error.response.data.message : error.response.data);
    } else if (error.request) {
      //console.log(error.request);
      throw new IdsRequestError();
    } else {
      //console.log(error.message);
      throw new IdsRequestSetupError();
    }
  });

  return ax;
};

module.exports = createOrUpdateObject;