'use strict';

var axios = require('axios');
var rax = require('@iris-platform/retryable-axios');
var isClientToken = require('../utils/is-client-token');

var _require = require('../utils/constants'),
    ApiVersion = _require.ApiVersion;

var _require2 = require('../errors'),
    IdsRequestError = _require2.IdsRequestError,
    IdsRequestSetupError = _require2.IdsRequestSetupError,
    InvalidOrMissingParameterError = _require2.InvalidOrMissingParameterError;

var requiredParam = require('../utils/required-param');

var getObjectsByPage = async function getObjectsByPage(_ref) {
  var _ref$url = _ref.url,
      url = _ref$url === undefined ? requiredParam('url') : _ref$url,
      _ref$token = _ref.token,
      token = _ref$token === undefined ? requiredParam('token') : _ref$token,
      _ref$className = _ref.className,
      className = _ref$className === undefined ? requiredParam('className') : _ref$className,
      _ref$start = _ref.start,
      start = _ref$start === undefined ? requiredParam('start') : _ref$start,
      _ref$count = _ref.count,
      count = _ref$count === undefined ? requiredParam('count') : _ref$count,
      userId = _ref.userId;

  var isClient = isClientToken(token);

  if (!isClient && !userId) throw new InvalidOrMissingParameterError('userId');

  var interceptorId = rax.attach();
  var ax = await axios({
    method: 'get',
    url: isClient ? url + '/' + ApiVersion + '/classes/' + className + '/objects/start/' + start + '/count/' + count : url + '/' + ApiVersion + '/classes/' + className + '/objects/start/' + start + '/count/' + count + '/userid/' + userId,
    timeout: 10000,
    headers: {
      "Content-Type": "application/json",
      "Authorization": 'Bearer ' + token
    },
    raxConfig: {}
  }).then(function (response) {
    return response.data;
  }).catch(function (error) {
    if (error.response) {
      throw new Error(error.response.data);
    } else if (error.request) {
      //console.log(error.request);
      throw new IdsRequestError();
    } else {
      //console.log(error.message);
      throw new IdsRequestSetupError();
    }
  });

  return ax;
};

module.exports = getObjectsByPage;