'use strict';

var axios = require('axios');
var rax = require('@iris-platform/retryable-axios');
var isClientToken = require('../utils/is-client-token');

var _require = require('../utils/constants'),
    ApiVersion = _require.ApiVersion;

var _require2 = require('../errors'),
    IdsRequestError = _require2.IdsRequestError,
    IdsRequestSetupError = _require2.IdsRequestSetupError,
    InvalidOrMissingParameterError = _require2.InvalidOrMissingParameterError,
    ExclusiveParametersError = _require2.ExclusiveParametersError;

var requiredParam = require('../utils/required-param');

var queryObjects = async function queryObjects(_ref) {
  var _ref$url = _ref.url,
      url = _ref$url === undefined ? requiredParam('url') : _ref$url,
      _ref$token = _ref.token,
      token = _ref$token === undefined ? requiredParam('token') : _ref$token,
      _ref$className = _ref.className,
      className = _ref$className === undefined ? requiredParam('className') : _ref$className,
      _ref$query = _ref.query,
      query = _ref$query === undefined ? requiredParam('query') : _ref$query,
      sort = _ref.sort,
      select = _ref.select,
      skip = _ref.skip,
      limit = _ref.limit,
      _ref$getCount = _ref.getCount,
      getCount = _ref$getCount === undefined ? false : _ref$getCount,
      _ref$getCountOnly = _ref.getCountOnly,
      getCountOnly = _ref$getCountOnly === undefined ? false : _ref$getCountOnly,
      userId = _ref.userId;

  var isClient = isClientToken(token);

  if (!isClient && !userId) throw new InvalidOrMissingParameterError('userId');

  var data = {
    query: query
  };

  if (sort) {
    data['sort'] = sort;
  }

  if (select) {
    data['select'] = select;
  }

  if (skip) {
    data['skip'] = skip;
  }

  if (limit) {
    data['limit'] = limit;
  }

  if (getCount && getCountOnly) {
    return Promise.reject(new ExclusiveParametersError('getCount', 'getCountOnly'));
  }

  if (getCount) {
    data['getCount'] = getCount;
  }

  if (getCountOnly) {
    data['getCountOnly'] = getCountOnly;
  }

  var interceptorId = rax.attach();
  var ax = await axios({
    method: 'post',
    url: isClient ? url + '/' + ApiVersion + '/query/' + className + '/objects' : url + '/' + ApiVersion + '/query/' + className + '/objects/userid/' + userId,
    timeout: 10000,
    headers: {
      "Content-Type": "application/json",
      "Authorization": 'Bearer ' + token
    },
    data: data,
    raxConfig: {
      httpMethodsToRetry: ['GET', 'PUT', 'HEAD', 'OPTIONS', 'DELETE', 'POST']
    }
  }).then(function (response) {
    return response.data;
  }).catch(function (error) {
    if (error.response) {
      throw new Error(error.response.data);
    } else if (error.request) {
      //console.log(error.request);
      throw new IdsRequestError();
    } else {
      //console.log(error.message);
      throw new IdsRequestSetupError();
    }
  });

  return ax;
};

module.exports = queryObjects;