'use strict';

var aum = require('@iris-platform/iris-aum-js-sdk');

module.exports = function serverAuth(_ref) {
  var clientId = _ref.clientId,
      secret = _ref.secret,
      domain = _ref.domain,
      authServer = _ref.authServer;

  var token = '';
  var _authServer = authServer;
  var auth = aum.AuthManagerFactory({
    authMgrApiUrl: authServer,
    apiVersion: 'v1.1',
    appkey: clientId,
    appsecret: secret
  });

  return Object.freeze({
    getToken: getToken,
    get serverUrl() {
      return _authServer;
    },
    get appDomain() {
      return domain;
    },
    emailLogin: emailLogin
  });

  function getToken() {
    if (isTokenValid()) {
      return Promise.resolve(token);
    }

    return refreshToken().then(function (token) {
      token = token;
      return token;
    });
  }

  function refreshToken() {
    return auth.serverLoginAsync().then(function (data) {
      return data.token;
    });
  }

  function isTokenValid() {
    if (token === '') {
      return false;
    }

    var decodedToken = auth.decodeToken(token);
    var exp = 0;
    var timeNow = 0;
    if (decodedToken) {
      exp = parseInt(decodedToken.exp, 10);
      timeNow = Math.floor(Date.now() / 1000);
    }
    if (exp <= timeNow) {
      return false;
    }

    return true;
  }

  function emailLogin(email, password) {
    return auth.emailLoginAsync(email, password);
  }
};