'use strict';

var requiredParam = require('./utils/required-param');
var createOrUpdateObject = require('./api/create-or-update');
var getObjectById = require('./api/get-object-by-id');

var NEW_OBJECT_ID = 'notsynched';

module.exports = function idsObject(_ref) {
  var _ref$auth = _ref.auth,
      auth = _ref$auth === undefined ? requiredParam('auth') : _ref$auth,
      _ref$idsServer = _ref.idsServer,
      idsServer = _ref$idsServer === undefined ? requiredParam('idsServer') : _ref$idsServer,
      _ref$className = _ref.className,
      className = _ref$className === undefined ? requiredParam('className') : _ref$className,
      attributes = _ref.attributes,
      userId = _ref.userId;

  var _className = className;
  var _attributes = attributes ? attributes : {};
  var _userId = userId;
  var _idsServer = idsServer;
  var _dirty = true;

  return Object.freeze({
    remove: remove,
    save: save,
    set: set,
    unset: unset,
    get: get,
    revert: revert,
    clear: clear,
    dirty: dirty,
    sync: sync,
    fromJSON: fromJSON,
    toJSON: toJSON,
    dispose: dispose
  });

  function _eventListener(eventPayload) {
    if (_attributes.objectId === eventPayload.payload.objectId) {
      _attributes = Object.assign({}, eventPayload.payload);
    }
  }

  function remove() {}

  async function save(attributes) {
    if (attributes) {
      Object.keys(attributes).forEach(function (key) {
        if (_attributes[key] !== attributes[key]) {
          _attributes[key] = attributes[key];
          _dirty = true;
        }
      });
    }

    if (_dirty) {
      var updateAttributes = Object.assign({}, _attributes);
      delete updateAttributes.objectId;
      delete updateAttributes.createdAt;
      delete updateAttributes.updatedAt;
      var token = await auth.getToken();
      var data = await createOrUpdateObject({
        url: _idsServer,
        token: token,
        className: _className,
        query: {
          objectId: _attributes.objectId ? _attributes.objectId : NEW_OBJECT_ID
        },
        object: updateAttributes,
        userId: _userId
      });
      _dirty = false;
      _attributes = data;
      return Promise.resolve(data);
    }

    return Promise.resolve(_attributes);
  }

  function set(attribute, value) {
    _attributes[attribute] = value;
  }

  function unset(attributes) {}

  function get(attribute) {
    return _attributes[attribute];
  }

  function revert() {}

  function clear() {}

  function dirty() {
    return _dirty;
  }

  async function sync() {
    var token = await auth.getToken();
    var data = await getObjectById({
      url: _idsServer,
      token: token,
      className: _className,
      objectId: _attributes.objectId,
      userId: _userId
    });
    _dirty = false;
    _attributes = data;
    return Promise.resolve(data);
  }

  function fromJSON() {
    var attributes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    _attributes = Object.assign({}, attributes);
  }

  function toJSON() {
    return Object.assign({}, _attributes);
  }
};