'use strict';

var requiredParam = require('./utils/required-param');
var queryObjects = require('./api/query-objects');

module.exports = function IdsQuery(_ref) {
  var _ref$auth = _ref.auth,
      auth = _ref$auth === undefined ? requiredParam('auth') : _ref$auth,
      _ref$idsServer = _ref.idsServer,
      idsServer = _ref$idsServer === undefined ? requiredParam('idsServer') : _ref$idsServer,
      _ref$className = _ref.className,
      className = _ref$className === undefined ? requiredParam('className') : _ref$className,
      userId = _ref.userId;

  var _className = className;
  var _result = [];
  var _userId = userId;
  var _idsServer = idsServer;
  var _query = void 0;
  var _sort = void 0;
  var _select = void 0;
  var _skip = void 0;
  var _limit = void 0;
  var _count = 0;

  return Object.freeze({
    find: find,
    sync: sync,
    getResults: getResults,
    getCount: getCount,
    toArray: toArray,
    toObjects: toObjects,
    dispose: dispose
  });

  function _eventListener(eventPayload) {
    sync();
  }

  async function find(_ref2) {
    var _ref2$query = _ref2.query,
        query = _ref2$query === undefined ? requiredParam('query') : _ref2$query,
        sort = _ref2.sort,
        select = _ref2.select,
        skip = _ref2.skip,
        limit = _ref2.limit;

    _query = query;
    _sort = sort;
    _select = select;
    _skip = skip;
    _limit = limit;

    var token = await auth.getToken();
    var data = await queryObjects({
      url: _idsServer,
      token: token,
      className: _className,
      query: query,
      sort: sort,
      select: select,
      skip: skip,
      limit: limit,
      getCount: true,
      getCountOnly: false,
      userId: _userId
    });

    _result = data.result;
    _count = data.count;
    return Promise.resolve(data.result);
  }

  async function sync() {
    var token = await auth.getToken();
    var data = await queryObjects({
      url: _idsServer,
      token: token,
      className: _className,
      query: _query,
      sort: _sort,
      select: _select,
      skip: _skip,
      limit: _limit,
      getCount: true,
      getCountOnly: false,
      userId: _userId
    });

    _result = data.result;
    _count = data.count;
    return Promise.resolve(data.result);
  }

  function getResults() {
    return _result;
  }

  function getCount() {
    return _count;
  }

  function toArray() {
    return JSON.parse(JSON.stringify(_result));
  }

  function toObjects() {}
};