'use strict';

var _require = require('./auth'),
    serverAuth = _require.serverAuth;

var idsServerUser = require('./ids-server-user');
var idsObject = require('./ids-object');
var idsQuery = require('./ids-query');
var requiredParam = require('./utils/required-param');

var _require2 = require('./errors'),
    NoUserError = _require2.NoUserError;

module.exports = function Ids() {
  var _auth = void 0;
  var _authServer = void 0;
  var _idsServer = void 0;

  return Object.freeze({
    initialize: initialize,
    user: user,
    object: object,
    query: query
  });

  function initialize() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        _ref$idsServer = _ref.idsServer,
        idsServer = _ref$idsServer === undefined ? requiredParam('idsServer') : _ref$idsServer,
        _ref$authServer = _ref.authServer,
        authServer = _ref$authServer === undefined ? requiredParam('authServer') : _ref$authServer;

    _idsServer = idsServer;
    _authServer = authServer;
  }

  function user(type) {
    var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref2$clientId = _ref2.clientId,
        clientId = _ref2$clientId === undefined ? requiredParam('clientId') : _ref2$clientId,
        secret = _ref2.secret,
        _ref2$domain = _ref2.domain,
        domain = _ref2$domain === undefined ? requiredParam('domain') : _ref2$domain;

    switch (type) {
      case 'client':
        throw new Error('Not implemented yet');
        break;

      case 'server':
        _auth = serverAuth({
          clientId: clientId,
          secret: secret,
          domain: domain,
          authServer: _authServer
        });
        return idsServerUser({
          auth: _auth
        });
        break;

      default:
        throw new Error('Invalid user type');
    }
  }

  function object(className) {
    var attributes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var userId = arguments[2];

    return idsObject({
      auth: _auth,
      idsServer: _idsServer,
      className: className,
      attributes: attributes,
      userId: userId
    });
  }

  function query(className, userId) {
    return idsQuery({
      auth: _auth,
      idsServer: _idsServer,
      className: className,
      userId: userId
    });
  }
};